@@ -22,6 +22,7 @@ from . import Image, ImageFile, ImagePalette
 from ._binary import i8
 from ._binary import i16be as i16
 from ._binary import i32be as i32
+from ._binary import si16be as si16
 
 MODES = {
     # (photoshop mode, bits) -> (pil mode, required channels)
@@ -154,14 +155,6 @@ class PsdImageFile(ImageFile.ImageFile):
         # return layer number (0=image, 1..max=layers)
         return self.frame
 
-    def load_prepare(self):
-        # create image memory if necessary
-        if not self.im or self.im.mode != self.mode or self.im.size != self.size:
-            self.im = Image.core.fill(self.mode, self.size, 0)
-        # create palette (optional)
-        if self.mode == "P":
-            Image.Image.load(self)
-
     def _close__fp(self):
         try:
             if self.__fp != self.fp:
@@ -179,7 +172,7 @@ def _layerinfo(fp, ct_bytes):
     def read(size):
         return ImageFile._safe_read(fp, size)
 
-    ct = i16(read(2))
+    ct = si16(read(2))
 
     # sanity check
     if ct_bytes < (abs(ct) * 20):
@@ -194,7 +187,6 @@ def _layerinfo(fp, ct_bytes):
         x1 = i32(read(4))
 
         # image info
-        info = []
         mode = []
         ct_types = i16(read(2))
         types = list(range(ct_types))
@@ -210,8 +202,7 @@ def _layerinfo(fp, ct_bytes):
                 m = "RGBA"[type]
 
             mode.append(m)
-            size = i32(read(4))
-            info.append((m, size))
+            read(4)  # size
 
         # figure out the image mode
         mode.sort()
@@ -228,26 +219,22 @@ def _layerinfo(fp, ct_bytes):
         read(12)  # filler
         name = ""
         size = i32(read(4))  # length of the extra data field
-        combined = 0
         if size:
             data_end = fp.tell() + size
 
             length = i32(read(4))
             if length:
                 fp.seek(length - 16, io.SEEK_CUR)
-            combined += length + 4
 
             length = i32(read(4))
             if length:
                 fp.seek(length, io.SEEK_CUR)
-            combined += length + 4
 
             length = i8(read(1))
             if length:
                 # Don't know the proper encoding,
                 # Latin-1 should be a good guess
                 name = read(length).decode("latin-1", "replace")
-            combined += length + 1
 
             fp.seek(data_end)
         layers.append((name, mode, (x0, y0, x1, y1)))
